#
# spec file for package perl-Math-BigInt-GMP
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Math-BigInt-GMP
Name:           perl-Math-BigInt-GMP
Version:        1.7001
Release:        1.6
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Backend library for Math::BigInt etc. based on GMP
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PJ/PJACKLAM/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Carp) >= 1.22
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.58
BuildRequires:  perl(Math::BigInt) >= 2.3.1
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(Carp) >= 1.22
Requires:       perl(Math::BigInt) >= 2.3.1
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gmp-devel
BuildRequires:  perl(Test::Pod) >= 1.22
BuildRequires:  perl(Test::Pod::Coverage) >= 1.08
# Version check does not work for perl packages before 5.22
%if 0%{?suse_version} <= 1320
BuildRequires:  perl-Math-BigInt >= 1.999714
Requires:       perl-Math-BigInt >= 1.999714
%endif
# MANUAL END

%description
Math::BigInt::GMP is a replacement library for Math::BigInt::Calc that
reimplements some of the Math::BigInt::Calc functions in XS. It can be used
via:

    use Math::BigInt lib => 'GMP';

This package contains a replacement (drop-in) module for Math::BigInt's core,
Math::BigInt::Calc.pm.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc BUGS CHANGES CREDITS README README.md TODO
%license LICENSE

%changelog
* Sun Jan  7 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.7001
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.7001 2024-01-06
  * Sync test files with Math-BigInt.
* Sat Dec 30 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.7000
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.7000 2023-12-29
  * Add new methods _to_hex(), _to_bin(), _to_oct(), _lcm(), _dfac(), _nok(),
    _fib(), and _lucas(). These are now in XS code rather than being inherited.
  1.6014 2023-12-27
  * Sync test files with Math-BigInt.
* Thu Sep 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.6013
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6013 2023-09-20
  * Sync test files with Math-BigInt.
  * Remove obsolete link to cpanratings.org.
* Tue Apr  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.6012
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6012 2023-04-03
  * Sync test files with Math-BigInt.
* Wed May 18 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.6011
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6011 2022-05-17
  * Sync test files with Math-BigInt.
* Fri Dec 31 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.6010
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6010 2021-12-29
  * Add static gmp_version() function (code provided by FGasper on GitHub).
  * Make t/01load.t display the output from gmp_version().
* Thu Sep 30 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.6009
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6009 2021-09-28
  * Sync test files with Math-BigInt.
* Sat Jul  3 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.6008
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6008 2021-07-02
  * Sync test files with Math-BigInt.
* Sat Oct 12 2019 <timueller+perl@suse.de>
- updated to 1.6007
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6007 2019-10-10
  * Sync test files with Math-BigInt.
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.6006
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  1.6006 2018-10-09
  * Update MANIFEST.SKIP.
  * Sync test files with Math-BigInt.
  * Better Makefile.PL.
* Tue Apr 24 2018 coolo@suse.com
- updated to 1.6005
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
* Mon Feb  6 2017 coolo@suse.com
- updated to 1.6004
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2017-02-05 v1.6004 pjacklam
  * Fix typos in POD.
  * Update link in SUPPORT section.
  * Minor improvements to the documentation (POD).
* Thu Jan 12 2017 coolo@suse.com
- updated to 1.6003
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
* Mon Dec  5 2016 coolo@suse.com
- updated to 1.6002
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2016-12-03 v1.6002 pjacklam
  * Use ExtUtils::MakeMaker rather than Module::Install in Makefile.PL
  * Don't use Devel::CheckLib. It fails on Windows even in cases where
    this distribution would build just fine.
  * Update BUGS file.
  * Remove author information in LICENSE file.
  * Inform that the TODO file is not up to date.
  * Remove INSTALL file. The information is in the README file.
* Fri Nov 25 2016 coolo@suse.com
- updated to 1.6001
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
* Thu Nov 17 2016 coolo@suse.com
- updated to 1.6000
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2016-11-15 v1.600 pjacklam
  * Sync test files with Math-BigInt-1.999800.
  * Update bundled Devel::CheckLib from v1.03 to v1.07.
  * Math::BigInt::GMP is now a subclass of Math::BigInt::Lib, so remove pure
    Perl methods from Math::BigInt::GMP that are implemented in the superclass
    Math::BigInt::Lib. The methods removed are _digit(), _num(), _nok(), and
    _log_int(). The version of _log_int() implemented in Math::BigInt::GMP was
    buggy anyway.
  * Fix _check() so it doesn't give a "use of uninitialized value" warning if
    given an undefined "object".
  * Trim whitespace in all files.
  * Better use of the functionality in Test::More in t/bigintg.t.
* Thu May  5 2016 coolo@suse.com
- updated to 1.51
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2016-04-25 v1.51 pjacklam
  * Sync test files with Math-BigInt-1.999719.
  2016-04-22 v1.50 pjacklam
  * Sync test files with Math-BigInt-1.999718.
* Mon Jan  4 2016 coolo@suse.com
- updated to 1.49
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2016-01-03 v1.49 pjacklam
  * Sync test files with Math-BigInt-1.999714.
* Sat Jan  2 2016 coolo@suse.com
- updated to 1.48
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2015-12-31 v1.48 pjacklam
  * Sync test files with Math-BigInt-1.999713.
* Tue Dec 15 2015 coolo@suse.com
- updated to 1.47
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2015-12-14 v1.47 pjacklam
  * Add patch from Gregor Herrmann (GREGOA) based on code by Dana Jacobsen
    (DANAJ) to fix problems with the new() method when Perl is compiled with
    support for 64-bit integers, but on platforms when the underlying OS is
    32-bit (CPAN RT #71548).
* Thu Dec 10 2015 opensuse@dstoecker.de
- updated to 1.46
* Thu Dec  3 2015 opensuse@dstoecker.de
- update to 1.45
  2015-11-09 v1.45 pjacklam
  * Sync test files with Math-BigInt-1.999709.
  * Required version of Test::More is 0.47.
  2015-10-29 v1.44 pjacklam
  * Sync test files with Math-BigInt-1.999707.
  * Update the README file.
  * Remove the files INSTALL and LICENSE as this information is already covered
    in the file README.
  * Replace 'use vars ...' with 'our ...'. We require a Perl newer than 5.6.0
    anyway.
  * Required version of Math-BigInt is now 1.999706.
  * Add 'Test::More' to TEST_REQUIRES in Makefile.PL.
  * Enable 'use warnings'. We require a Perl newer than 5.6.0 anyway.
  * Add 'assertlib.*\.exe' to MANIFEST.SKIP, since make generates temporary
    files like 'assertlibzxjE4WfG.exe' on Cygwin.
  2015-09-21 v1.43 pjacklam
  * Sync test files with Math-BigInt-1.999703.
  * Required version of Math-BigInt is now 1.999703.
  * Update author information.
  2015-09-17 v1.42 pjacklam
  * Sync test files with Math-BigInt-1.999702.
  * Required version of Math-BigInt is now 1.999702.
  2015-09-11 v1.41 pjacklam
  lib/Math/BigInt/GMP.pm
  * Updated version number.
  Makefile.PL
  * Updated required version of Math::BigInt.
  t/bigfltpm.inc
  * Synced tests with the Math-BigInt distribution.
  t/bigfltpm.t
  * Updated number of tests.
  t/bigintpm.inc
  * Synced tests with the Math-BigInt distribution.
  t/bigintpm.t
  * Updated number of tests.
* Sun Aug 23 2015 coolo@suse.com
- updated to 1.40
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2015-08-18 v1.40 pjacklam
  CHANGES
  * Add changes for the newest release.
  * Reorder change entries into descending chronological order.
  lib/Devel/CheckLib.pm
  * Update bundled Devel::CheckLib from v1.01 to v1.03.
  Makefile.PL
  * Update required version of Math-BigInt to 1.9994.
  t/01load.t
  * Improve formatting of module version information.
  t/bigfltpm.t
  * Use the correct backend, in this case Math::BigInt::GMP.
  * Skip test specific for the Math::BigInt::Calc backend.
  t/bigintpm.inc
  * Rather than an early exit(), use skip() to skip tests.
  t/bigintpm.t
  * Use the correct backend, in this case Math::BigInt::GMP.
  t/biglog.t
  * Use the correct backend, in this case Math::BigInt::GMP. This was correct
    in v1.21, but has been wrong since then.
  t/bigroot.t
  * Use the correct backend, in this case Math::BigInt::GMP. This was correct
    up until v1.32, but has been wrong since then.
  lib/Math/BigInt/GMP.pm
  * Increment Math::BigInt::GMP version number to 1.40.
  2015-08-17 v1.39 pjacklam
  * Updated test files with those from Math-BigInt-1.9997.
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.38
  see /usr/share/doc/packages/perl-Math-BigInt-GMP/CHANGES
  2014-04-03 v1.38 pjacklam
  * Updated test files from the Math::BigInt distribution (Peter John Acklam).
  * Updated POD (Peter John Acklam)
  * Updated bundled Devel::CheckLib from v0.93 to v1.01 (Peter John Acklam).
* Fri Nov 18 2011 coolo@suse.com
- update to 1.37
  * Updated test files from the Math::BigInt distribution (Peter John Acklam).
  * Updated bundled Devel::CheckLib from v0.92 to v0.93 (Peter John Acklam).
  * Math::BigInt::GMP now requires Math::BigInt v1.997 (Peter John Acklam).
  * Include "^MYMETA\.(yml|json)\z" in MANIFEST.SKIP. Whereas META.* are
    generated by the distribution author at packaging time, MYMETA.* are
    generated by the end user at configure time after any dynamic dependencies
    are known. (Peter John Acklam)
  * Changed Makefile.PL so that a "make dist" makes a META.yml and META.json.
    (Peter John Acklam)
  * Updated common test files from the Math::BigInt distribution. (Peter John
    Acklam)
* Fri May 20 2011 coolo@novell.com
- updated to 1.36, see Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Jul 16 2010 chris@computersalat.de
- initial package 1.24
  * created by cpanspec 1.78
